from enum import Enum


class Paths(Enum):
    JOBS_IN = 'JOBIN'
    QUEUED_JOBS = 'JOBQ'
    INVENTORY = 'INV'
    STATION1_QUEUE_SIZE = 'S1Q'
    STATION1_UTILISATION = 'S1UTIL'
    STATION2_QUEUE_SIZE = 'S3Q'
    STATION2_UTILISATION = 'S3UTIL'
    STATION3_QUEUE_SIZE = 'S3Q'
    STATION3_UTILISATION = 'S3UTIL'
    COMPLETED_JOB_COUNT = 'JOBOUT'
    LEAD_TIMES = 'JOBT'
    REVENUES = 'JOBREV'
    CASH = 'CASH'
    LOGIN = 'CheckAccess'
